@@ -6,11 +6,15 @@ if (interactive()) {
     # save a raw version in the package - historical and this way it is versioned properly
     writeLines(webFile, "inst/ui-examples/cX-function.R")
 
+    # fixes to URLs if required - these are known issues with the URLs in the test file
+    webFile <- gsub("https://www.canvasxpress.org/data/cX-olympicMedals",
+                    "https://www.canvasxpress.org/data/cX-OlympicMedals", webFile)
+
     # save a localized version for testing
     pkgFile <- data.frame(orig = webFile, stringsAsFactors = F) %>%
         mutate(isfileline   = grepl('read.table\\("http.*canvasxpress.org', orig),
                #exclude specific larger files from url conversion - must match #canvasxpress.data file filter
-               isfileline   = (!grepl('cX-codiv|LungCancinoma', orig) & isfileline),
+               isfileline   = (!grepl('cX-codiv|LungCancinoma|visium|Olympic|exprtcga', orig) & isfileline),
                filename     = ifelse(isfileline, gsub('.*/', '', orig), NA),
                filename     = ifelse(is.na(filename), NA, gsub('\\.txt".*$', '', filename))) %>%
         rowwise() %>%
