@@ -1,5 +1,6 @@
 context("canvasXpress Charts - Segregation Ordering")
 
+
 y <- read.table(get_data("cX-toothgrowth-dat.txt.gz"), header = TRUE, sep = "\t", quote = "", row.names = 1, fill = TRUE, check.names = FALSE, stringsAsFactors = FALSE)
 x <- read.table(get_data("cX-toothgrowth-smp.txt.gz"), header = TRUE, sep = "\t", quote = "", row.names = 1, fill = TRUE, check.names = FALSE, stringsAsFactors = FALSE)
 
@@ -18,9 +19,7 @@ test_that("segregation ordering - Samples", {
                            title                   = "Sorting descending by dose",
                            xAxisTitle              = "len",
                            sortDir                 = "descending",
-                           afterRender             = list(list('sortSamplesByCategory', list("dose")))
-    )
+                           afterRender             = list(list('sortSamplesByCategory', list("dose"))))
 
     check_ui_test(result)
 })
-
