@@ -65,3 +65,7 @@ test_that("cXscatter2d13", {
 test_that("cXscatter2d14", {
     check_ui_test(cXscatter2d14())
 })
+
+test_that("cXscatter2d15", {
+    check_ui_test(cXscatter2d15())
+})
